<?php
/*
Plugin Name: Card Converter
Plugin URI: http://mtdewvirus.com/code/
Description: Replace playing card abbreviations with a CSS playing card. Allows you to write &lt;card&gt;As&lt;/card&gt;, but WP to display a CSS representation of the Ace of spades.
Author: Nick Momrik
Version: 1.13
Author URI: http://mtdewvirus.com/
*/ 

function mdv_card_converter($text) {
	// Check what is in between <card> and </card>.
	$output = preg_replace("'<card>([a-zA-Z0-9\?]*)</card>'e", "mdv_convert_card('\\1')", $text);

	return $output;
}

function mdv_valid_card($card) {
	//This function is always given a valid card
	$output = "";
	$len = strlen($card);

	//No suit
	if ($len == 1) {
		$output = '<span class="nocardsuit">'.$card.'&nbsp;</span>';
	}
	//Suited card
	else {
		$suit = substr($card, 1, 1);
		//Red suit
		if (preg_match("/[DH]/", $suit)) {
			$card = preg_replace("/D/", "&diams;", $card);
			$card = preg_replace("/H/", "&hearts;", $card);
			$output = '<span class="redcardsuit">'.$card.'</span>';
		}
		//Black suit
		else {
			$card = preg_replace("/C/", "&clubs;", $card);
			$card = preg_replace("/S/", "&spades;", $card);
			$output = '<span class="blackcardsuit">'.$card.'</span>';
		}
	}
	
	return $output;
}

function mdv_convert_card($card) {
	$output = "";
	$invalid_message = "[invalid card]"; //Text to display for invalid card input
	$inv = '<span class="invalidcard">'.$invalid_message.'</span>';

	//Make some format changes to the input
	$card = strtoupper($card);
	$card = str_replace("10", "T", $card);
	$card = str_replace("1", "A", $card);

	$len = strlen($card);
	if ($len == 1) {
		//Unsuited card
		if (preg_match("/[2-9TJQKAX\?]/", $card)) {
			$output = mdv_valid_card($card);
		}
		//Suit w/o card rank
		else if (preg_match("/[CDHS]/", $card)) {
			$card = "X".$card;
			$output = mdv_valid_card($card);
		}
		//Invalid card
		else {
			$output = $inv;
		}
	}
	else if ($len == 2) {
		if (preg_match("/[2-9TJQKAX\?][CDHS]/", $card)) {
			$output = mdv_valid_card($card);
		}
		else {
			$output = $inv;
		}
	}
	else {
		$output = $inv;
	}

	return $output;

}

function mdv_card_converter_css() {
//Adds CSS to head
echo <<<END
	<style type='text/css'>
		.redcardsuit, .blackcardsuit, .nocardsuit, .invalidcard {
			padding: 0px 1px 0px 1px;
			margin: 0px 1px 0px 1px;
			background-color:#ffc;
			border:1px solid #888;
			font: 15px Courier;
			line-height: 150%;
		}
		.redcardsuit {
			color: red;
		}
		.blackcardsuit {
			color: black;
		}
		.nocardsuit {
			color: blue;
		}
	</style>
END;
}

// Define custom tags to allow span tag
define('CUSTOM_TAGS', true);
$allowedtags = array(
				'a' => array(
					'href' => array(),
					'title' => array(),
					'rel' => array()),
				'abbr' => array('title' => array()),
				'acronym' => array('title' => array()),
				'b' => array(),
				'blockquote' => array('cite' => array()),
				'card' => array(),
				'code' => array(),
				'em' => array(),
				'i' => array(),
				'span' => array('class' => array()),
				'strike' => array(),
				'strong' => array(),
				);

add_filter('the_content', 'mdv_card_converter');
add_filter('the_excerpt', 'mdv_card_converter');
add_filter('comment_text', 'mdv_card_converter', 9);
add_action('wp_head', 'mdv_card_converter_css');
?>